@@ -33,16 +33,31 @@
 
 #' Return Associated single decrement from absolute rate of decrement
 #'
-#' @param object a life table 
+#' @param object a mdj object 
 #' @param x age
-#' @param t period (usually 1)
-#' @param decrement 
+#' @param t period (default 1)
+#' @param decrement type (necessary)
 #'
 #' @return a single value (AST)
-.qxt.ard.asd<-function(object, x, t=1, decrement) {
+#' 
+#' @examples 
+#' #Creating the valdez mdf
+#' 
+#'  valdezDf<-data.frame(
+#' x=c(50:54),
+#' lx=c(4832555,4821937,4810206,4797185,4782737),
+#' hearth=c(5168, 5363, 5618, 5929, 6277),
+#' accidents=c(1157, 1206, 1443, 1679,2152),
+#' other=c(4293,5162,5960,6840,7631))
+#' valdezMdt<-new("mdt",name="ValdezExample",table=valdezDf) 
+#' 
+#' qxt.prime.fromMdt(object=valdezMdt,x=53,decrement="other")
+#' 
+qxt.prime.fromMdt<-function(object, x, t=1, decrement) {
   out <- NA
   if (missing(decrement)) stop("Error! decrement must be specified");
-  out<-1-(1-qxt(object = object,x = x,t=t))^(qxt(object = object,x = x,t=t,decrement = decrement)/qxt(object = object,x = x,t=t))
+  fraction <- (qxt(object = object,x = x,t=1,decrement = decrement)/qxt(object = object,x = x,t=1))
+  out <- 1 - (1-qxt(object = object,x = x,t=t, fractional="linear"))^fraction
   return(out)
 }
 
