@@ -4,6 +4,7 @@
 ###############################################################################
 
 
+
 # loading the markovchain package
 
 .onAttach <- function(libname, pkgname) {
@@ -25,4 +26,8 @@
 # .onLoad <- function(libname, pkgname) {
 #   tools::vignetteEngine("rmarkdown", weave = vweave, tangle = vtangle,
 #                         pattern = "[.]Rmd$", package = "knitr")
-# }
\ No newline at end of file
+# }
+
+#' @useDynLib lifecontingencies
+#' @importFrom Rcpp sourceCpp
+NULL
\ No newline at end of file
